tkmilan.var
===========

.. automodule:: tkmilan.var

   
   
   .. rubric:: Module Attributes

   .. autosummary::
   
      Boolean
      Double
      Int
      String
      objT
      spvT
      MAP_VALIDATIONS
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      trace
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Limit
      LimitBounded
      LimitUnbounded
      ObjectList
      Spec
      SpecCountable
      SpecParsed
      StaticList
      StaticMap
      StringList
      aggregator
      nothing
   
   

   
   
   



